@@ -13,7 +13,7 @@ import inspect
 import logging
 
 
-__version_info__ = (0, 3)
+__version_info__ = (0, 4)
 __version__ = '.'.join(map(str, __version_info__))
 
 
@@ -54,7 +54,8 @@ class Deproxy:
         self._endpoints = []
 
     def make_request(self, url, method='GET', headers=None, request_body='',
-                     handler_function=default_handler):
+                     handler_function=default_handler,
+                     add_default_headers=True):
         """Make an HTTP request to the given url and return a MessageChain."""
         logger.debug('')
 
@@ -82,11 +83,13 @@ class Deproxy:
         urlparts[1] = ''
         path = urlparse.urlunsplit(urlparts)
 
-        try_add_value_case_insensitive(headers, 'Host', host)
-        try_add_value_case_insensitive(headers, 'Accept', '*/*')
-        try_add_value_case_insensitive(headers, 'Accept-Encoding',
-                                       'identity, deflate, compress, gzip')
-        try_add_value_case_insensitive(headers, 'User-Agent', version_string)
+        if add_default_headers:
+            try_add_value_case_insensitive(headers, 'Host', host)
+            try_add_value_case_insensitive(headers, 'Accept', '*/*')
+            try_add_value_case_insensitive(headers, 'Accept-Encoding',
+                                           'identity, deflate, compress, gzip')
+            try_add_value_case_insensitive(headers, 'User-Agent',
+                                           version_string)
 
         request = Request(method, path, headers, request_body)
 
@@ -426,6 +429,13 @@ class DeproxyEndpoint:
             resp = handler_function(incoming_request)
             logger.debug('returned from handler_function')
 
+            add_default_headers = True
+            if type(resp) == tuple:
+                logger.debug('Handler gave back a tuple: {}'.format(resp))
+                if len(resp) > 1:
+                    add_default_headers = resp[1]
+                resp = resp[0]
+
             found = try_get_value_case_insensitive(resp.headers,
                                                    request_id_header_name)
             if not found and request_id is not None:
@@ -439,7 +449,8 @@ class DeproxyEndpoint:
             else:
                 self.deproxy.add_orphaned_handling(h)
 
-            self.send_response(wfile, resp)
+            self.send_response(wfile, resp,
+                               add_default_headers=add_default_headers)
 
             wfile.flush()
 
@@ -572,7 +583,7 @@ class DeproxyEndpoint:
 
         self.send_response(response)
 
-    def send_response(self, wfile, response):
+    def send_response(self, wfile, response, add_default_headers=True):
         """
         Send the given Response over the socket. Add Server and Date headers
         if not already present.
@@ -588,16 +599,19 @@ class DeproxyEndpoint:
                     (response.code, message))
 
         headers = dict(response.headers)
-        lowers = {}
+        if add_default_headers:
+            lowers = {}
 
-        for name, value in response.headers.items():
-            name_lower = name.lower()
-            lowers[name_lower] = value
+            for name, value in response.headers.items():
+                name_lower = name.lower()
+                lowers[name_lower] = value
 
-        if 'server' not in lowers:
-            headers['Server'] = version_string
-        if 'date' not in lowers:
-            headers['Date'] = self.date_time_string()
+            if 'server' not in lowers:
+                headers['Server'] = version_string
+            if 'date' not in lowers:
+                headers['Date'] = self.date_time_string()
+        else:
+            logger.debug('Don\'t add default response headers.')
 
         for name, value in headers.iteritems():
             wfile.write("%s: %s\r\n" % (name, value))
